pub struct RdpServer { /* private fields */ }Expand description
RDP Server
A server is created to listen for connections. After the connection sequence is finalized using the provided security mechanism, the server can:
- receive display updates from a
RdpServerDisplayand forward them to the client - receive input events from a client and forward them to an
RdpServerInputHandler
Example
use ironrdp_server::{RdpServer, RdpServerInputHandler, RdpServerDisplay, RdpServerDisplayUpdates};
fn make_tls_acceptor() -> TlsAcceptor {
/* snip */
}
fn make_input_handler() -> impl RdpServerInputHandler {
/* snip */
}
fn make_display_handler() -> impl RdpServerDisplay {
/* snip */
}
let tls_acceptor = make_tls_acceptor();
let input_handler = make_input_handler();
let display_handler = make_display_handler();
let mut server = RdpServer::builder()
.with_addr(([127, 0, 0, 1], 3389))
.with_tls(tls_acceptor)
.with_input_handler(input_handler)
.with_display_handler(display_handler)
.build();
server.run().await;Implementations
Sourceimpl RdpServer
impl RdpServer
pub fn new( opts: RdpServerOptions, handler: Box<dyn RdpServerInputHandler>, display: Box<dyn RdpServerDisplay>, sound_factory: Option<Box<dyn SoundServerFactory>>, cliprdr_factory: Option<Box<dyn CliprdrServerFactory>>, ) -> Self
pub fn builder() -> RdpServerBuilder<WantsAddr>
pub fn event_sender(&self) -> &UnboundedSender<ServerEvent>
pub async fn run_connection(&mut self, stream: TcpStream) -> Result<()>
pub async fn run(&mut self) -> Result<()>
pub fn get_svc_processor<T: SvcProcessor + 'static>(&mut self) -> Option<&mut T>
pub fn get_channel_id_by_type<T: SvcProcessor + 'static>( &self, ) -> Option<StaticChannelId>
pub fn set_credentials(&mut self, creds: Option<Credentials>)