pub trait RdpServerDisplayUpdates {
// Required method
fn next_update<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = Result<Option<DisplayUpdate>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Display Updates receiver for an RDP server
The RDP server will repeatedly call the next_update method to receive
display updates which will then be encoded and sent to the client
See RdpServerDisplay example.
Required Methods
Sourcefn next_update<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = Result<Option<DisplayUpdate>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn next_update<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = Result<Option<DisplayUpdate>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Cancel safety
This method MUST be cancellation safe because it is used in a
tokio::select! statement. If some other branch completes first, it
MUST be guaranteed that no data is lost.